@@ -2,42 +2,7 @@ from __future__ import annotations
 
 from bidict import bidict
 
-
-class BoardVector:
-    def __init__(self, x, y):
-        self._x: int = x
-        self._y: int = y
-
-    def __eq__(self, other):
-        if isinstance(other, BoardVector):
-            return self.x == other.x and self.y == other.y
-        return False
-
-    def __hash__(self):
-        return hash((self.x, self.y))
-
-    def __add__(self, other: BoardVector):
-        return BoardVector(self.x + other.x, self.y + other.y)
-
-    def __str__(self):
-        return f"({self.x}, {self.y})"
-
-    def __repr__(self):
-        return f"vector({self.x}, {self.y})"
-
-    @property
-    def x(self) -> int:
-        return self._x
-
-    @property
-    def y(self) -> int:
-        return self._y
-
-    def pair(self) -> tuple[int, int]:
-        return self.x, self.y
-
-
-vector = BoardVector  # alias for BoardVector
+from .vector import BoardVector
 
 
 class BoardException(Exception):
@@ -66,18 +31,24 @@ class ObjectNotFound(BoardException):
 
 class BoardObject:
     def __init__(self):
-        self._board: Board = None
+        self._board: Board | None = None
 
     @property
     def board(self):
         return self._board
 
-    def get_pos(self):
+    def get_pos(self) -> BoardVector:
         return self.board.get_object_pos(self)
 
     def move(self, transform: BoardVector):
         return self.board.move_object(self, transform)
 
+    def adjacent(self):
+        for pos in self.get_pos().adjacent:
+            obj = self.board.get_object_at(pos)
+            if obj is not None:
+                yield pos, obj
+
 
 class BoardValue(BoardObject):
     def __init__(self, val):
